@@ -86,7 +86,7 @@ sub AUTOLOAD {
 tie %Config, 'Config', {
     archlibexp => '/usr/lib/perl5/5.40/armv6j-linux',
     archname => 'armv6j-linux',
-    cc => 'armv6j-softfp-linux-gnueabi-gcc',
+    cc => 'armv6j-softfp-linux-gnueabit64-gcc',
     d_readlink => 'define',
     d_symlink => 'define',
     dlext => 'so',
@@ -96,9 +96,9 @@ tie %Config, 'Config', {
     inc_version_list => ' ',
     intsize => '4',
     ldlibpthname => 'LD_LIBRARY_PATH',
-    libpth => '/usr/lib',
+    libpth => '/usr/lib /lib',
     osname => 'linux',
-    osvers => '6.12.23-gentoo-dist',
+    osvers => '6.12.53-gentoo-dist',
     path_sep => ':',
     privlibexp => '/usr/lib/perl5/5.40',
     scriptdir => '/usr/bin',
