@@ -10,7 +10,7 @@ use strict;
 use warnings;
 our ( %Config, $VERSION );
 
-$VERSION = "5.040000";
+$VERSION = "5.040002";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,11 +56,11 @@ sub import {
     return;
 }
 
-die "$0: Perl lib version (5.40.0) doesn't match executable '$^X' version ($])"
+die "$0: Perl lib version (5.40.2) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.40.0
-    or die sprintf "%s: Perl lib version (5.40.0) doesn't match executable '$^X' version (%vd)", $0, $^V;
+$^V eq 5.40.2
+    or die sprintf "%s: Perl lib version (5.40.2) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -96,7 +96,7 @@ tie %Config, 'Config', {
     inc_version_list => ' ',
     intsize => '4',
     ldlibpthname => 'LD_LIBRARY_PATH',
-    libpth => '/usr/local/lib64 /lib64 /usr/lib64 /usr/lib',
+    libpth => '/usr/local/lib64 /lib64 /usr/lib64 /usr/lib /lib/../lib64 /usr/lib/../lib64 /lib',
     osname => 'linux',
     osvers => '6.1.60-gentoo-dist-hardened',
     path_sep => ':',
@@ -107,5 +107,5 @@ tie %Config, 'Config', {
     so => 'so',
     useithreads => undef,
     usevendorprefix => 'define',
-    version => '5.40.0',
+    version => '5.40.2',
 };
